C
C
C     Transforming output of the San Pedro Martir UBV Cuentapulsos photometer
C     !!!format used in 2007!!!                          into Data B of HEC22
C
C     release 2   October 5, 2007
C
C                 Enables combination of data obtained with and
C                 without the attenuating filter which means that
C                 dead-time is applied in this program and
C                 m u s t   n o t   be applied in HEC22
C
C                 This version is oriented to bright stars
C                 and assumes that the main body of the data was observed
C                 through the attenuating filter
C
C       release 1.1 has a pre-defined dead-time 5D-8 and allows
C                   to select another one by using a negative value
C                   for VN
C
      IMPLICIT REAL*8 (A-H,O-Z)
      DIMENSION TX(5),FIL(3)
      CHARACTER*1 ZN,ZK(3),F
      CHARACTER*6 NGT
      CHARACTER*8 OBS
      CHARACTER*12 INP,OUT
C
      COMMON /DTC/ DT
C
C
C     Definition of special data values
C
      DT=5.0D-08
      DATA ZK/1HC,1Hs,1HB/
      DATA FIL/0.06984D0,0.06862D0,0.06422D0/
C
C     Input formats
C
  101 FORMAT(A1)
  102 FORMAT(3A4,2I4)
  103 FORMAT(37X,A1)
  104 FORMAT(8X,3I2,5X,I4,3X,A1,19X,I2,4X,F4.0,F9.0,F7.2)
C
C     Output formats
C
  201 FORMAT(A1,A12)
  202 FORMAT(5A8)
  203 FORMAT(F3.0,I3,I5,4H 330,8X,6H -420./
     1'-7.6975556',21X,3H31.,7X,3H2.6,18X,3H7.0,5X,'SanPedro')
  204 FORMAT(I1,I4,2I3,F9.4,1X,F10.3)
  205 FORMAT(5H    0)
  206 FORMAT(10A8)
  207 FORMAT('Night ',A6,' SPM 0.84-m UBV ',A8,1X,'VN ',I4,1HV,1X)
C
C     Formats of error messages
C
  301 FORMAT(' Error: Star ',3A4,' is missing in table of objects')
  302 FORMAT(' Error in data sequence at time ',3I2)
  303 FORMAT(' Unexpected filter No.',I3,' at time ',3I2,
     *       'and deflection ',F10.4)
C
    7 PRINT *,'Creating HEC22 type B data  Rel. 1.1 May 8, 2002'
C
      PRINT *,'Input file of San Pedro Martir data?'
      READ(*,'(A)') INP
      PRINT *,'Output HEC22 data file?'
      READ(*,'(A)') OUT
      OPEN(1,FILE=INP,STATUS='OLD')
      OPEN(2,FILE=OUT,STATUS='NEW')
C
C
C
      PRINT *,'Night No.? (max. 6 characters, e.g.: 25/92)'
      READ(*,'(A)') NGT
      PRINT *,'Observer? (max. 8 characters)'
      READ(*,'(A)') OBS
      PRINT *,'High voltage in volts? (integer up to 4 digits)'
      READ(*,*) J
      IF(J.GE.0) GO TO 2
      PRINT *,'Enter a new value of dead-time coef. for 1 sec.'
      READ(*,*) DT
      J=-J
    2 WRITE(2,207) NGT,OBS,J
      WRITE(*,207) NGT,OBS,J
      PRINT *,'Comments on quality, weather etc. [max. 40 characters!]'
      PRINT *,'<                                     >'
      READ(*,206) TX
      WRITE(2,202) TX
      PRINT *,'Date of the beginning of night (day-month-year)?'
      READ(*,*) D,M,J
      WRITE(2,203) D,M,J
C
C
C     Input of stellar deflections
C
    8 READ(1,101,END=10) ZN
      IF(ZN.EQ.ZK(1)) GO TO 8
      BACKSPACE 1
      READ(1,103) ZN
      BACKSPACE 1
      READ(1,104) JH,JM,JS,N,F,JF,TI,V,Q
      TS=JS+5D-1*TI
      IF(JF.EQ.1) JC=3
      IF(JF.EQ.2) JC=2
      IF(JF.EQ.3) JC=1
      IF(JF.LT.1.OR.JF.GT.3) WRITE(2,303) JF,JH,JM,JS,V
      V=V/TI
      CALL DEAD(V)
      IF(F.NE.ZK(3)) GO TO 1
      V=V*FIL(JC)
    1 WRITE(2,204) JC,N,JH,JM,TS,V
      GO TO 8
C
C
   10 WRITE(2,205)
      PRINT *,'Another night? Write 1;  Stop? Write 0'
      READ(*,*) J
      IF(J.NE.0) GO TO 7
      STOP 7
      END
C
C
      SUBROUTINE DEAD(A)
C
C     CALCULATION OF THE DEAD-TIME CORRECTION
C
      IMPLICIT REAL*8(A-H,O-Z)
      COMMON /DTC/ T
C
      IF(A.EQ.0D0) RETURN
      B=A
    1 C=B
      B=A*DEXP(T*B)
      IF(DABS((B-C)/B).GT.1.D-8) GO TO 1
      A=B
      RETURN
      END
